==> temporal-sdk-1.23.2-sources.jar: io/temporal/internal/statemachines/StartChildWorkflowExecutionParameters.java <==
/*
 * Copyright (C) 2022 Temporal Technologies, Inc. All Rights Reserved.
 *
 * Copyright (C) 2012-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Modifications copyright (C) 2017 Uber Technologies, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this material except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.temporal.internal.statemachines;

import io.temporal.api.command.v1.StartChildWorkflowExecutionCommandAttributes;
import io.temporal.workflow.ChildWorkflowCancellationType;

public final class StartChildWorkflowExecutionParameters {

  private final StartChildWorkflowExecutionCommandAttributes.Builder request;
  private final ChildWorkflowCancellationType cancellationType;

  public StartChildWorkflowExecutionParameters(
      StartChildWorkflowExecutionCommandAttributes.Builder request,
      ChildWorkflowCancellationType cancellationType) {
    this.request = request;
    this.cancellationType = cancellationType;
  }

  public StartChildWorkflowExecutionCommandAttributes.Builder getRequest() {
    return request;
  }

  public ChildWorkflowCancellationType getCancellationType() {
    return cancellationType;
  }
}

==> temporal-sdk-1.29.0-sources.jar: io/temporal/internal/statemachines/StartChildWorkflowExecutionParameters.java <==
/*
 * Copyright (C) 2022 Temporal Technologies, Inc. All Rights Reserved.
 *
 * Copyright (C) 2012-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Modifications copyright (C) 2017 Uber Technologies, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this material except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.temporal.internal.statemachines;

import io.temporal.api.command.v1.StartChildWorkflowExecutionCommandAttributes;
import io.temporal.api.sdk.v1.UserMetadata;
import io.temporal.workflow.ChildWorkflowCancellationType;
import javax.annotation.Nullable;

public final class StartChildWorkflowExecutionParameters {

  private final StartChildWorkflowExecutionCommandAttributes.Builder request;
  private final ChildWorkflowCancellationType cancellationType;
  private final UserMetadata metadata;

  public StartChildWorkflowExecutionParameters(
      StartChildWorkflowExecutionCommandAttributes.Builder request,
      ChildWorkflowCancellationType cancellationType,
      @Nullable UserMetadata metadata) {
    this.request = request;
    this.cancellationType = cancellationType;
    this.metadata = metadata;
  }

  public StartChildWorkflowExecutionCommandAttributes.Builder getRequest() {
    return request;
  }

  public ChildWorkflowCancellationType getCancellationType() {
    return cancellationType;
  }

  public @Nullable UserMetadata getMetadata() {
    return metadata;
  }
}
